@@ -1,28 +1,25 @@
 package snmp_trap
 
 import (
-	"bufio"
-	"bytes"
 	"fmt"
 	"net"
-	"os/exec"
+	"os"
+	"path/filepath"
 	"strconv"
 	"strings"
-	"sync"
 	"time"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
-	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/plugins/inputs"
+	"github.com/sleepinggenius2/gosmi"
+	"github.com/sleepinggenius2/gosmi/types"
 
 	"github.com/gosnmp/gosnmp"
 )
 
 var defaultTimeout = config.Duration(time.Second * 5)
 
-type execer func(config.Duration, string, ...string) ([]byte, error)
-
 type mibEntry struct {
 	mibName string
 	oidText string
@@ -32,6 +29,7 @@ type SnmpTrap struct {
 	ServiceAddress string          `toml:"service_address"`
 	Timeout        config.Duration `toml:"timeout"`
 	Version        string          `toml:"version"`
+	Path           []string        `toml:"path"`
 
 	// Settings for version 3
 	// Values: "noAuthNoPriv", "authNoPriv", "authPriv"
@@ -44,19 +42,15 @@ type SnmpTrap struct {
 	PrivProtocol string `toml:"priv_protocol"`
 	PrivPassword string `toml:"priv_password"`
 
-	acc      telegraf.Accumulator
-	listener *gosnmp.TrapListener
-	timeFunc func() time.Time
-	errCh    chan error
+	acc        telegraf.Accumulator
+	listener   *gosnmp.TrapListener
+	timeFunc   func() time.Time
+	lookupFunc func(string) (mibEntry, error)
+	errCh      chan error
 
 	makeHandlerWrapper func(gosnmp.TrapHandlerFunc) gosnmp.TrapHandlerFunc
 
 	Log telegraf.Logger `toml:"-"`
-
-	cacheLock sync.Mutex
-	cache     map[string]mibEntry
-
-	execCmd execer
 }
 
 var sampleConfig = `
@@ -68,6 +62,10 @@ var sampleConfig = `
   ## 1024.  See README.md for details
   ##
   # service_address = "udp://:162"
+  ##
+  ## Path to mib files
+  # path = ["/usr/share/snmp/mibs"]
+  ##
   ## Timeout running snmptranslate command
   # timeout = "5s"
   ## Snmp version, defaults to 2c
@@ -104,6 +102,7 @@ func init() {
 	inputs.Add("snmp_trap", func() telegraf.Input {
 		return &SnmpTrap{
 			timeFunc:       time.Now,
+			lookupFunc:     lookup,
 			ServiceAddress: "udp://:162",
 			Timeout:        defaultTimeout,
 			Version:        "2c",
@@ -111,20 +110,50 @@ func init() {
 	})
 }
 
-func realExecCmd(timeout config.Duration, arg0 string, args ...string) ([]byte, error) {
-	cmd := exec.Command(arg0, args...)
-	var out bytes.Buffer
-	cmd.Stdout = &out
-	err := internal.RunTimeout(cmd, time.Duration(timeout))
+func (s *SnmpTrap) Init() error {
+	// must init, append path for each directory, load module for every file
+	// or gosmi will fail without saying why
+	gosmi.Init()
+	err := s.getMibsPath()
 	if err != nil {
-		return nil, err
+		s.Log.Errorf("Could not get path %v", err)
 	}
-	return out.Bytes(), nil
+	return nil
 }
 
-func (s *SnmpTrap) Init() error {
-	s.cache = map[string]mibEntry{}
-	s.execCmd = realExecCmd
+func (s *SnmpTrap) getMibsPath() error {
+	var folders []string
+	for _, mibPath := range s.Path {
+		gosmi.AppendPath(mibPath)
+		folders = append(folders, mibPath)
+		err := filepath.Walk(mibPath, func(path string, info os.FileInfo, err error) error {
+			if info.Mode()&os.ModeSymlink != 0 {
+				s, _ := os.Readlink(path)
+				folders = append(folders, s)
+			}
+			return nil
+		})
+		if err != nil {
+			s.Log.Errorf("Filepath could not be walked %v", err)
+		}
+		for _, folder := range folders {
+			err := filepath.Walk(folder, func(path string, info os.FileInfo, err error) error {
+				if info.IsDir() {
+					gosmi.AppendPath(path)
+				} else if info.Mode()&os.ModeSymlink == 0 {
+					_, err := gosmi.LoadModule(info.Name())
+					if err != nil {
+						s.Log.Errorf("Module could not be loaded %v", err)
+					}
+				}
+				return nil
+			})
+			if err != nil {
+				s.Log.Errorf("Filepath could not be walked %v", err)
+			}
+		}
+		folders = []string{}
+	}
 	return nil
 }
 
@@ -248,6 +277,7 @@ func (s *SnmpTrap) Start(acc telegraf.Accumulator) error {
 
 func (s *SnmpTrap) Stop() {
 	s.listener.Close()
+	defer gosmi.Exit()
 	err := <-s.errCh
 	if nil != err {
 		s.Log.Errorf("Error stopping trap listener %v", err)
@@ -281,7 +311,7 @@ func makeTrapHandler(s *SnmpTrap) gosnmp.TrapHandlerFunc {
 			}
 
 			if trapOid != "" {
-				e, err := s.lookup(trapOid)
+				e, err := s.lookupFunc(trapOid)
 				if err != nil {
 					s.Log.Errorf("Error resolving V1 OID, oid=%s, source=%s: %v", trapOid, tags["source"], err)
 					return
@@ -319,7 +349,7 @@ func makeTrapHandler(s *SnmpTrap) gosnmp.TrapHandlerFunc {
 
 				var e mibEntry
 				var err error
-				e, err = s.lookup(val)
+				e, err = s.lookupFunc(val)
 				if nil != err {
 					s.Log.Errorf("Error resolving value OID, oid=%s, source=%s: %v", val, tags["source"], err)
 					return
@@ -337,7 +367,7 @@ func makeTrapHandler(s *SnmpTrap) gosnmp.TrapHandlerFunc {
 				value = v.Value
 			}
 
-			e, err := s.lookup(v.Name)
+			e, err := s.lookupFunc(v.Name)
 			if nil != err {
 				s.Log.Errorf("Error resolving OID oid=%s, source=%s: %v", v.Name, tags["source"], err)
 				return
@@ -366,48 +396,16 @@ func makeTrapHandler(s *SnmpTrap) gosnmp.TrapHandlerFunc {
 	}
 }
 
-func (s *SnmpTrap) lookup(oid string) (e mibEntry, err error) {
-	s.cacheLock.Lock()
-	defer s.cacheLock.Unlock()
-	var ok bool
-	if e, ok = s.cache[oid]; !ok {
-		// cache miss.  exec snmptranslate
-		e, err = s.snmptranslate(oid)
-		if err == nil {
-			s.cache[oid] = e
-		}
-		return e, err
-	}
-	return e, nil
-}
-
-func (s *SnmpTrap) clear() {
-	s.cacheLock.Lock()
-	defer s.cacheLock.Unlock()
-	s.cache = map[string]mibEntry{}
-}
-
-func (s *SnmpTrap) load(oid string, e mibEntry) {
-	s.cacheLock.Lock()
-	defer s.cacheLock.Unlock()
-	s.cache[oid] = e
-}
-
-func (s *SnmpTrap) snmptranslate(oid string) (e mibEntry, err error) {
-	var out []byte
-	out, err = s.execCmd(s.Timeout, "snmptranslate", "-Td", "-Ob", "-m", "all", oid)
+func lookup(oid string) (e mibEntry, err error) {
+	var node gosmi.SmiNode
+	node, err = gosmi.GetNodeByOID(types.OidMustFromString(oid))
 
+	// ensure modules are loaded or node will be empty (might not error)
 	if err != nil {
 		return e, err
 	}
 
-	scanner := bufio.NewScanner(bytes.NewBuffer(out))
-	ok := scanner.Scan()
-	if err = scanner.Err(); !ok && err != nil {
-		return e, err
-	}
-
-	e.oidText = scanner.Text()
+	e.oidText = node.RenderQualified()
 
 	i := strings.Index(e.oidText, "::")
 	if i == -1 {
