@@ -1,9 +1,9 @@
+//go:build linux
 // +build linux
 
 package zfs
 
 import (
-	"io/ioutil"
 	"os"
 	"testing"
 
@@ -182,67 +182,6 @@ scatter_page_alloc_retry        4    99311
 scatter_sg_table_retry          4    99221
 `
 
-const dbufcachestatsContents = `
-15 1 0x01 11 2992 6257505590736 8516276189184
-name                            type data
-size                            4    242688
-size_max                        4    338944
-max_bytes                       4    62834368
-lowater_bytes                   4    56550932
-hiwater_bytes                   4    69117804
-total_evicts                    4    0
-hash_collisions                 4    0
-hash_elements                   4    31
-hash_elements_max               4    32
-hash_chains                     4    0
-hash_chain_max                  4    0
-`
-
-const dnodestatsContents = `
-10 1 0x01 28 7616 6257498525011 8671911551753
-name                            type data
-dnode_hold_dbuf_hold            4    0
-dnode_hold_dbuf_read            4    0
-dnode_hold_alloc_hits           4    1460
-dnode_hold_alloc_misses         4    0
-dnode_hold_alloc_interior       4    0
-dnode_hold_alloc_lock_retry     4    0
-dnode_hold_alloc_lock_misses    4    0
-dnode_hold_alloc_type_none      4    0
-dnode_hold_free_hits            4    2
-dnode_hold_free_misses          4    0
-dnode_hold_free_lock_misses     4    0
-dnode_hold_free_lock_retry      4    0
-dnode_hold_free_overflow        4    0
-dnode_hold_free_refcount        4    0
-dnode_hold_free_txg             4    0
-dnode_allocate                  4    2
-dnode_reallocate                4    0
-dnode_buf_evict                 4    6
-dnode_alloc_next_chunk          4    1
-dnode_alloc_race                4    0
-dnode_alloc_next_block          4    0
-dnode_move_invalid              4    0
-dnode_move_recheck1             4    0
-dnode_move_recheck2             4    0
-dnode_move_special              4    0
-dnode_move_handle               4    0
-dnode_move_rwlock               4    0
-dnode_move_active               4    0
-`
-
-const vdevmirrorcachestatsContents = `
-18 1 0x01 7 1904 6257505684227 9638257816287
-name                            type data
-rotating_linear                 4    0
-rotating_offset                 4    0
-rotating_seek                   4    0
-non_rotating_linear             4    0
-non_rotating_seek               4    0
-preferred_found                 4    0
-preferred_not_found             4    43
-`
-
 var testKstatPath = os.TempDir() + "/telegraf/proc/spl/kstat/zfs"
 
 func TestZfsPoolMetrics(t *testing.T) {
@@ -252,10 +191,10 @@ func TestZfsPoolMetrics(t *testing.T) {
 	err = os.MkdirAll(testKstatPath+"/HOME", 0755)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/HOME/io", []byte(poolIoContents), 0644)
+	err = os.WriteFile(testKstatPath+"/HOME/io", []byte(poolIoContents), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/arcstats", []byte(arcstatsContents), 0644)
+	err = os.WriteFile(testKstatPath+"/arcstats", []byte(arcstatsContents), 0644)
 	require.NoError(t, err)
 
 	poolMetrics := getPoolMetrics()
@@ -291,25 +230,25 @@ func TestZfsGeneratesMetrics(t *testing.T) {
 	err = os.MkdirAll(testKstatPath+"/HOME", 0755)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/HOME/io", []byte(""), 0644)
+	err = os.WriteFile(testKstatPath+"/HOME/io", []byte(""), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/arcstats", []byte(arcstatsContents), 0644)
+	err = os.WriteFile(testKstatPath+"/arcstats", []byte(arcstatsContents), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/zfetchstats", []byte(zfetchstatsContents), 0644)
+	err = os.WriteFile(testKstatPath+"/zfetchstats", []byte(zfetchstatsContents), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/zil", []byte(zilContents), 0644)
+	err = os.WriteFile(testKstatPath+"/zil", []byte(zilContents), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/fm", []byte(fmContents), 0644)
+	err = os.WriteFile(testKstatPath+"/fm", []byte(fmContents), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/dmu_tx", []byte(dmuTxContents), 0644)
+	err = os.WriteFile(testKstatPath+"/dmu_tx", []byte(dmuTxContents), 0644)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/abdstats", []byte(abdstatsContents), 0644)
+	err = os.WriteFile(testKstatPath+"/abdstats", []byte(abdstatsContents), 0644)
 	require.NoError(t, err)
 
 	intMetrics := getKstatMetricsAll()
@@ -332,7 +271,7 @@ func TestZfsGeneratesMetrics(t *testing.T) {
 	err = os.MkdirAll(testKstatPath+"/STORAGE", 0755)
 	require.NoError(t, err)
 
-	err = ioutil.WriteFile(testKstatPath+"/STORAGE/io", []byte(""), 0644)
+	err = os.WriteFile(testKstatPath+"/STORAGE/io", []byte(""), 0644)
 	require.NoError(t, err)
 
 	tags = map[string]string{
