@@ -1,6 +1,7 @@
-package timestream_test
+package timestream
 
 import (
+	"context"
 	"fmt"
 	"reflect"
 	"sort"
@@ -9,13 +10,11 @@ import (
 	"testing"
 	"time"
 
-	"github.com/aws/aws-sdk-go/aws/awserr"
-
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/timestreamwrite"
+	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/aws/aws-sdk-go-v2/service/timestreamwrite"
+	"github.com/aws/aws-sdk-go-v2/service/timestreamwrite/types"
 	"github.com/influxdata/telegraf"
 	internalaws "github.com/influxdata/telegraf/config/aws"
-	ts "github.com/influxdata/telegraf/plugins/outputs/timestream"
 	"github.com/influxdata/telegraf/testutil"
 
 	"github.com/stretchr/testify/assert"
@@ -34,40 +33,37 @@ var time2 = time.Date(2009, time.November, 10, 23, 0, 0, 0, time.UTC)
 
 const time2Epoch = "1257894000"
 
-const timeUnit = "SECONDS"
-
 const metricName1 = "metricName1"
 const metricName2 = "metricName2"
 
-type mockTimestreamClient struct {
-}
+type mockTimestreamClient struct{}
 
-func (m *mockTimestreamClient) CreateTable(*timestreamwrite.CreateTableInput) (*timestreamwrite.CreateTableOutput, error) {
+func (m *mockTimestreamClient) CreateTable(context.Context, *timestreamwrite.CreateTableInput, ...func(*timestreamwrite.Options)) (*timestreamwrite.CreateTableOutput, error) {
 	return nil, nil
 }
-func (m *mockTimestreamClient) WriteRecords(*timestreamwrite.WriteRecordsInput) (*timestreamwrite.WriteRecordsOutput, error) {
+func (m *mockTimestreamClient) WriteRecords(context.Context, *timestreamwrite.WriteRecordsInput, ...func(*timestreamwrite.Options)) (*timestreamwrite.WriteRecordsOutput, error) {
 	return nil, nil
 }
-func (m *mockTimestreamClient) DescribeDatabase(*timestreamwrite.DescribeDatabaseInput) (*timestreamwrite.DescribeDatabaseOutput, error) {
+func (m *mockTimestreamClient) DescribeDatabase(context.Context, *timestreamwrite.DescribeDatabaseInput, ...func(*timestreamwrite.Options)) (*timestreamwrite.DescribeDatabaseOutput, error) {
 	return nil, fmt.Errorf("hello from DescribeDatabase")
 }
 
 func TestConnectValidatesConfigParameters(t *testing.T) {
 	assertions := assert.New(t)
-	ts.WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (ts.WriteClient, error) {
+	WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (WriteClient, error) {
 		return &mockTimestreamClient{}, nil
 	}
 	// checking base arguments
-	noDatabaseName := ts.Timestream{Log: testutil.Logger{}}
+	noDatabaseName := Timestream{Log: testutil.Logger{}}
 	assertions.Contains(noDatabaseName.Connect().Error(), "DatabaseName")
 
-	noMappingMode := ts.Timestream{
+	noMappingMode := Timestream{
 		DatabaseName: tsDbName,
 		Log:          testutil.Logger{},
 	}
 	assertions.Contains(noMappingMode.Connect().Error(), "MappingMode")
 
-	incorrectMappingMode := ts.Timestream{
+	incorrectMappingMode := Timestream{
 		DatabaseName: tsDbName,
 		MappingMode:  "foo",
 		Log:          testutil.Logger{},
@@ -75,24 +71,24 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 	assertions.Contains(incorrectMappingMode.Connect().Error(), "single-table")
 
 	// multi-table arguments
-	validMappingModeMultiTable := ts.Timestream{
+	validMappingModeMultiTable := Timestream{
 		DatabaseName: tsDbName,
-		MappingMode:  ts.MappingModeMultiTable,
+		MappingMode:  MappingModeMultiTable,
 		Log:          testutil.Logger{},
 	}
 	assertions.Nil(validMappingModeMultiTable.Connect())
 
-	singleTableNameWithMultiTable := ts.Timestream{
+	singleTableNameWithMultiTable := Timestream{
 		DatabaseName:    tsDbName,
-		MappingMode:     ts.MappingModeMultiTable,
+		MappingMode:     MappingModeMultiTable,
 		SingleTableName: testSingleTableName,
 		Log:             testutil.Logger{},
 	}
 	assertions.Contains(singleTableNameWithMultiTable.Connect().Error(), "SingleTableName")
 
-	singleTableDimensionWithMultiTable := ts.Timestream{
+	singleTableDimensionWithMultiTable := Timestream{
 		DatabaseName: tsDbName,
-		MappingMode:  ts.MappingModeMultiTable,
+		MappingMode:  MappingModeMultiTable,
 		SingleTableDimensionNameForTelegrafMeasurementName: testSingleTableDim,
 		Log: testutil.Logger{},
 	}
@@ -100,25 +96,25 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		"SingleTableDimensionNameForTelegrafMeasurementName")
 
 	// single-table arguments
-	noTableNameMappingModeSingleTable := ts.Timestream{
+	noTableNameMappingModeSingleTable := Timestream{
 		DatabaseName: tsDbName,
-		MappingMode:  ts.MappingModeSingleTable,
+		MappingMode:  MappingModeSingleTable,
 		Log:          testutil.Logger{},
 	}
 	assertions.Contains(noTableNameMappingModeSingleTable.Connect().Error(), "SingleTableName")
 
-	noDimensionNameMappingModeSingleTable := ts.Timestream{
+	noDimensionNameMappingModeSingleTable := Timestream{
 		DatabaseName:    tsDbName,
-		MappingMode:     ts.MappingModeSingleTable,
+		MappingMode:     MappingModeSingleTable,
 		SingleTableName: testSingleTableName,
 		Log:             testutil.Logger{},
 	}
 	assertions.Contains(noDimensionNameMappingModeSingleTable.Connect().Error(),
 		"SingleTableDimensionNameForTelegrafMeasurementName")
 
-	validConfigurationMappingModeSingleTable := ts.Timestream{
+	validConfigurationMappingModeSingleTable := Timestream{
 		DatabaseName:    tsDbName,
-		MappingMode:     ts.MappingModeSingleTable,
+		MappingMode:     MappingModeSingleTable,
 		SingleTableName: testSingleTableName,
 		SingleTableDimensionNameForTelegrafMeasurementName: testSingleTableDim,
 		Log: testutil.Logger{},
@@ -126,18 +122,18 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 	assertions.Nil(validConfigurationMappingModeSingleTable.Connect())
 
 	// create table arguments
-	createTableNoMagneticRetention := ts.Timestream{
+	createTableNoMagneticRetention := Timestream{
 		DatabaseName:           tsDbName,
-		MappingMode:            ts.MappingModeMultiTable,
+		MappingMode:            MappingModeMultiTable,
 		CreateTableIfNotExists: true,
 		Log:                    testutil.Logger{},
 	}
 	assertions.Contains(createTableNoMagneticRetention.Connect().Error(),
 		"CreateTableMagneticStoreRetentionPeriodInDays")
 
-	createTableNoMemoryRetention := ts.Timestream{
+	createTableNoMemoryRetention := Timestream{
 		DatabaseName:           tsDbName,
-		MappingMode:            ts.MappingModeMultiTable,
+		MappingMode:            MappingModeMultiTable,
 		CreateTableIfNotExists: true,
 		CreateTableMagneticStoreRetentionPeriodInDays: 3,
 		Log: testutil.Logger{},
@@ -145,9 +141,9 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 	assertions.Contains(createTableNoMemoryRetention.Connect().Error(),
 		"CreateTableMemoryStoreRetentionPeriodInHours")
 
-	createTableValid := ts.Timestream{
+	createTableValid := Timestream{
 		DatabaseName:           tsDbName,
-		MappingMode:            ts.MappingModeMultiTable,
+		MappingMode:            MappingModeMultiTable,
 		CreateTableIfNotExists: true,
 		CreateTableMagneticStoreRetentionPeriodInDays: 3,
 		CreateTableMemoryStoreRetentionPeriodInHours:  3,
@@ -156,9 +152,9 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 	assertions.Nil(createTableValid.Connect())
 
 	// describe table on start arguments
-	describeTableInvoked := ts.Timestream{
+	describeTableInvoked := Timestream{
 		DatabaseName:            tsDbName,
-		MappingMode:             ts.MappingModeMultiTable,
+		MappingMode:             MappingModeMultiTable,
 		DescribeDatabaseOnStart: true,
 		Log:                     testutil.Logger{},
 	}
@@ -169,31 +165,30 @@ type mockTimestreamErrorClient struct {
 	ErrorToReturnOnWriteRecords error
 }
 
-func (m *mockTimestreamErrorClient) CreateTable(*timestreamwrite.CreateTableInput) (*timestreamwrite.CreateTableOutput, error) {
+func (m *mockTimestreamErrorClient) CreateTable(context.Context, *timestreamwrite.CreateTableInput, ...func(*timestreamwrite.Options)) (*timestreamwrite.CreateTableOutput, error) {
 	return nil, nil
 }
-func (m *mockTimestreamErrorClient) WriteRecords(*timestreamwrite.WriteRecordsInput) (*timestreamwrite.WriteRecordsOutput, error) {
+func (m *mockTimestreamErrorClient) WriteRecords(context.Context, *timestreamwrite.WriteRecordsInput, ...func(*timestreamwrite.Options)) (*timestreamwrite.WriteRecordsOutput, error) {
 	return nil, m.ErrorToReturnOnWriteRecords
 }
-func (m *mockTimestreamErrorClient) DescribeDatabase(*timestreamwrite.DescribeDatabaseInput) (*timestreamwrite.DescribeDatabaseOutput, error) {
+func (m *mockTimestreamErrorClient) DescribeDatabase(context.Context, *timestreamwrite.DescribeDatabaseInput, ...func(*timestreamwrite.Options)) (*timestreamwrite.DescribeDatabaseOutput, error) {
 	return nil, nil
 }
 
 func TestThrottlingErrorIsReturnedToTelegraf(t *testing.T) {
 	assertions := assert.New(t)
-
-	ts.WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (ts.WriteClient, error) {
+	WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (WriteClient, error) {
 		return &mockTimestreamErrorClient{
-			awserr.New(timestreamwrite.ErrCodeThrottlingException,
-				"Throttling Test", nil),
+			ErrorToReturnOnWriteRecords: &types.ThrottlingException{Message: aws.String("Throttling Test")},
 		}, nil
 	}
-	plugin := ts.Timestream{
-		MappingMode:  ts.MappingModeMultiTable,
+
+	plugin := Timestream{
+		MappingMode:  MappingModeMultiTable,
 		DatabaseName: tsDbName,
 		Log:          testutil.Logger{},
 	}
-	plugin.Connect()
+	assertions.NoError(plugin.Connect())
 	input := testutil.MustMetric(
 		metricName1,
 		map[string]string{"tag1": "value1"},
@@ -209,19 +204,18 @@ func TestThrottlingErrorIsReturnedToTelegraf(t *testing.T) {
 
 func TestRejectedRecordsErrorResultsInMetricsBeingSkipped(t *testing.T) {
 	assertions := assert.New(t)
-
-	ts.WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (ts.WriteClient, error) {
+	WriteFactory = func(credentialConfig *internalaws.CredentialConfig) (WriteClient, error) {
 		return &mockTimestreamErrorClient{
-			awserr.New(timestreamwrite.ErrCodeRejectedRecordsException,
-				"RejectedRecords Test", nil),
+			ErrorToReturnOnWriteRecords: &types.RejectedRecordsException{Message: aws.String("RejectedRecords Test")},
 		}, nil
 	}
-	plugin := ts.Timestream{
-		MappingMode:  ts.MappingModeMultiTable,
+
+	plugin := Timestream{
+		MappingMode:  MappingModeMultiTable,
 		DatabaseName: tsDbName,
 		Log:          testutil.Logger{},
 	}
-	plugin.Connect()
+	assertions.NoError(plugin.Connect())
 	input := testutil.MustMetric(
 		metricName1,
 		map[string]string{"tag1": "value1"},
@@ -271,7 +265,7 @@ func TestTransformMetricsSkipEmptyMetric(t *testing.T) {
 		dimensions:    map[string]string{testSingleTableDim: metricName1},
 		measureValues: map[string]string{"value": "20"},
 	})
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2, input3},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
 
@@ -287,7 +281,7 @@ func TestTransformMetricsSkipEmptyMetric(t *testing.T) {
 		dimensions:    map[string]string{},
 		measureValues: map[string]string{"value": "20"},
 	})
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2, input3},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
 }
@@ -326,7 +320,7 @@ func TestTransformMetricsRequestsAboveLimitAreSplit(t *testing.T) {
 		dimensions:    map[string]string{"tag1": "value1", testSingleTableDim: metricName1},
 		measureValues: map[string]string{"value_supported" + strconv.Itoa(maxRecordsInWriteRecordsCall+1): "10"},
 	})
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		inputs,
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
 
@@ -342,7 +336,7 @@ func TestTransformMetricsRequestsAboveLimitAreSplit(t *testing.T) {
 		dimensions:    map[string]string{"tag1": "value1"},
 		measureValues: map[string]string{"value_supported" + strconv.Itoa(maxRecordsInWriteRecordsCall+1): "10"},
 	})
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		inputs,
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
 }
@@ -378,7 +372,7 @@ func TestTransformMetricsDifferentDimensionsSameTimestampsAreWrittenSeparate(t *
 		measureValues: map[string]string{"value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
 
@@ -395,7 +389,7 @@ func TestTransformMetricsDifferentDimensionsSameTimestampsAreWrittenSeparate(t *
 		measureValues: map[string]string{"value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
 }
@@ -431,7 +425,7 @@ func TestTransformMetricsSameDimensionsDifferentDimensionValuesAreWrittenSeparat
 		measureValues: map[string]string{"value_supported1": "20"},
 	})
 
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
 
@@ -448,7 +442,7 @@ func TestTransformMetricsSameDimensionsDifferentDimensionValuesAreWrittenSeparat
 		measureValues: map[string]string{"value_supported1": "20"},
 	})
 
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
 }
@@ -484,7 +478,7 @@ func TestTransformMetricsSameDimensionsDifferentTimestampsAreWrittenSeparate(t *
 		measureValues: map[string]string{"value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
 
@@ -501,7 +495,7 @@ func TestTransformMetricsSameDimensionsDifferentTimestampsAreWrittenSeparate(t *
 		measureValues: map[string]string{"value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
 }
@@ -531,7 +525,7 @@ func TestTransformMetricsSameDimensionsSameTimestampsAreWrittenTogether(t *testi
 		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20", "value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
@@ -542,7 +536,7 @@ func TestTransformMetricsSameDimensionsSameTimestampsAreWrittenTogether(t *testi
 		measureValues: map[string]string{"value_supported1": "10", "value_supported2": "20", "value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResultMultiTable})
 }
@@ -578,7 +572,7 @@ func TestTransformMetricsDifferentMetricsAreWrittenToDifferentTablesInMultiTable
 		measureValues: map[string]string{"value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1SingleTable, expectedResult2SingleTable})
 
@@ -595,7 +589,7 @@ func TestTransformMetricsDifferentMetricsAreWrittenToDifferentTablesInMultiTable
 		measureValues: map[string]string{"value_supported3": "30"},
 	})
 
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{input1, input2},
 		[]*timestreamwrite.WriteRecordsInput{expectedResult1MultiTable, expectedResult2MultiTable})
 }
@@ -616,7 +610,7 @@ func TestTransformMetricsUnsupportedFieldsAreSkipped(t *testing.T) {
 		measureValues: map[string]string{"value_supported1": "10"},
 	})
 
-	comparisonTest(t, ts.MappingModeSingleTable,
+	comparisonTest(t, MappingModeSingleTable,
 		[]telegraf.Metric{metricWithUnsupportedField},
 		[]*timestreamwrite.WriteRecordsInput{expectedResultSingleTable})
 
@@ -627,7 +621,7 @@ func TestTransformMetricsUnsupportedFieldsAreSkipped(t *testing.T) {
 		measureValues: map[string]string{"value_supported1": "10"},
 	})
 
-	comparisonTest(t, ts.MappingModeMultiTable,
+	comparisonTest(t, MappingModeMultiTable,
 		[]telegraf.Metric{metricWithUnsupportedField},
 		[]*timestreamwrite.WriteRecordsInput{expectedResultMultiTable})
 }
@@ -637,10 +631,10 @@ func comparisonTest(t *testing.T,
 	telegrafMetrics []telegraf.Metric,
 	timestreamRecords []*timestreamwrite.WriteRecordsInput,
 ) {
-	var plugin ts.Timestream
+	var plugin Timestream
 	switch mappingMode {
-	case ts.MappingModeSingleTable:
-		plugin = ts.Timestream{
+	case MappingModeSingleTable:
+		plugin = Timestream{
 			MappingMode:  mappingMode,
 			DatabaseName: tsDbName,
 
@@ -648,8 +642,8 @@ func comparisonTest(t *testing.T,
 			SingleTableDimensionNameForTelegrafMeasurementName: testSingleTableDim,
 			Log: testutil.Logger{},
 		}
-	case ts.MappingModeMultiTable:
-		plugin = ts.Timestream{
+	case MappingModeMultiTable:
+		plugin = Timestream{
 			MappingMode:  mappingMode,
 			DatabaseName: tsDbName,
 			Log:          testutil.Logger{},
@@ -710,20 +704,20 @@ type SimpleInput struct {
 }
 
 func buildExpectedRecords(i SimpleInput) *timestreamwrite.WriteRecordsInput {
-	var tsDimensions []*timestreamwrite.Dimension
+	var tsDimensions []types.Dimension
 	for k, v := range i.dimensions {
-		tsDimensions = append(tsDimensions, &timestreamwrite.Dimension{
+		tsDimensions = append(tsDimensions, types.Dimension{
 			Name:  aws.String(k),
 			Value: aws.String(v),
 		})
 	}
 
-	var tsRecords []*timestreamwrite.Record
+	var tsRecords []types.Record
 	for k, v := range i.measureValues {
-		tsRecords = append(tsRecords, &timestreamwrite.Record{
+		tsRecords = append(tsRecords, types.Record{
 			MeasureName:      aws.String(k),
 			MeasureValue:     aws.String(v),
-			MeasureValueType: aws.String("DOUBLE"),
+			MeasureValueType: types.MeasureValueTypeDouble,
 		})
 	}
 
@@ -731,10 +725,10 @@ func buildExpectedRecords(i SimpleInput) *timestreamwrite.WriteRecordsInput {
 		DatabaseName: aws.String(tsDbName),
 		TableName:    aws.String(i.tableName),
 		Records:      tsRecords,
-		CommonAttributes: &timestreamwrite.Record{
+		CommonAttributes: &types.Record{
 			Dimensions: tsDimensions,
 			Time:       aws.String(i.t),
-			TimeUnit:   aws.String(timeUnit),
+			TimeUnit:   types.TimeUnitSeconds,
 		},
 	}
 
